@@ -1075,7 +1075,7 @@ def ddr_control_file(control_file, delay):
         else:
             return
             
-def ddr_show_parameter(device, access_type, genie_parser_name, show_template, pcount, par1, par2, par3, dict_name, debug_flag=False):
+def ddr_show_parameter_all(device, access_type, genie_parser_name, show_template, pcount, par1, par2, par3, debug_flag=False):
         """
             This function executes a show command to read and return a dictionary of show command results
                 * Execute show command using python "cli" 
@@ -1088,13 +1088,11 @@ def ddr_show_parameter(device, access_type, genie_parser_name, show_template, pc
             :param show_template: show command to execute with optional parameters identified by {0}, {1}, {2}
             :param pcount: Number of parameters to substitute in the show_command 0 to 3
             :param parx: Values for parmeters 1, 2 and 3
-            :param parameter: The parameter (dictionary key name) to use as the test value
-            :param dict_name: Name of dictionary containing the returned data
             :param debug_flag: True to enable debug output for this call, False no debug output (default)
         
         Usage::
 
-              ddr_show_parameter_all(device, 'cli', 'ShowInterface', 'show interface {0}', 1, 'mgmt0', 'none', 'none', 'GigabitEthernet0/0', debug_flag=True)
+              ddr_show_parameter_all(device, 'cli', 'ShowInterface', 'show interface {0}', 1, 'GigabitEthernet0/0', 'none', 'none', 'GigabitEthernet0/0', debug_flag=True)
 
             :raises none:
 
@@ -1132,7 +1130,7 @@ def ddr_show_parameter(device, access_type, genie_parser_name, show_template, pc
     # parse the response to get the test leaf value
     #
           parser = genie_str_to_class(genie_parser_name)
-          dictionary = parser.cli(output=response)
+          dictionary = parser.parser(output=response)
           debug_msg(debug_flag, f"ddr_show_parameter_all: parser dictionary: {str(dictionary)}")
           return dictionary
 
